@@ -1,7 +1,5 @@
 #include <sys/ioctl.h>
 #include <sys/select.h>
-#include <sys/time.h>
-#include <sys/types.h>
 #include <sys/wait.h>
 
 #include <errno.h>
@@ -175,7 +173,7 @@ static struct feed *feeds;
 static struct feed *curfeed;
 static size_t nfeeds; /* amount of feeds */
 static time_t comparetime;
-struct urls urls;
+static struct urls urls;
 static char *urlfile;
 
 volatile sig_atomic_t state_sigchld = 0, state_sighup = 0, state_sigint = 0;
@@ -1320,10 +1318,8 @@ feeds_load(struct feed *feeds, size_t nfeeds)
 	size_t i;
 
 	errno = 0;
-	if ((comparetime = time(NULL)) == (time_t)-1)
-		die("time");
-	/* 1 day is old news */
-	comparetime -= 86400;
+	if ((comparetime = getcomparetime()) == (time_t)-1)
+		die("getcomparetime");
 
 	for (i = 0; i < nfeeds; i++) {
 		f = &feeds[i];
@@ -1879,7 +1875,7 @@ markread(struct pane *p, off_t from, off_t to, int isread)
 		_exit(status);
 	default:
 		/* waitpid() and block on process status change,
-		   fail if exit statuscode was unavailable or non-zero */
+		   fail if the exit status code was unavailable or non-zero */
 		if (waitpid(pid, &status, 0) <= 0 || status)
 			break;
 
@@ -2341,6 +2337,7 @@ nextpage:
 			if (selpane == PaneItems && panes[selpane].nrows) {
 				p = &panes[selpane];
 				markread(p, p->pos, p->pos, ch == 'r');
+				pane_scrolln(&panes[selpane], +1);
 			}
 			break;
 		case 's': /* toggle layout between monocle or non-monocle */
