@@ -1,5 +1,3 @@
-#include <sys/types.h>
-
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -7,7 +5,6 @@
 
 #include "util.h"
 
-static struct feed f;
 static char *prefixpath = "/", *host = "127.0.0.1", *port = "70"; /* default */
 static char *line;
 static size_t linesize;
@@ -121,6 +118,7 @@ printfeed(FILE *fpitems, FILE *fpin, struct feed *f)
 int
 main(int argc, char *argv[])
 {
+	struct feed f;
 	FILE *fpitems, *fpindex, *fp;
 	char *name, *p;
 	int i;
@@ -137,10 +135,8 @@ main(int argc, char *argv[])
 			err(1, "pledge");
 	}
 
-	if ((comparetime = time(NULL)) == (time_t)-1)
-		errx(1, "time");
-	/* 1 day is old news */
-	comparetime -= 86400;
+	if ((comparetime = getcomparetime()) == (time_t)-1)
+		errx(1, "getcomparetime");
 
 	if ((p = getenv("SFEED_GOPHER_HOST")))
 		host = p;
